Core team
=========

* Matthew Westcott (Torchbox)
* Karl Hobley (Torchbox)
* Tom Dyson (Torchbox)
* Thibaud Colas (Torchbox)
* Janneke Janssen (Lukkien)
* Mike Dingjan (Lab Digital)
* Bertrand Bordage (NoriPyt)
* Loïc Teixeira (Springload)
* Andy Chosak (consumerfinance.gov)
* Will Barton (consumerfinance.gov)
* LB Johnston
* Coen van der Kamp (Four Digits)
* Codie Roelf (Praekelt)
* Lisa Adams (Praekelt)
* Naomi Morduch Toubman
* Kalob Taulien
* Jonny Scholes (Neon Jungle)
* Andy Babic (Torchbox)
* Dan Braghis (Torchbox)
* Dawn Wages
* Jacob Topp-Mugglestone (Torchbox)

Core team alumni
================

* Josh Barr
* Tim Heap
* Mikalai Radchuk

Contributors
============

* David Cranwell
* Helen Chapman
* Balazs Endresz
* Neal Todd
* Paul Hallett
* Serafeim Papastefanos
* Łukasz Bołdys
* peterarenot
* Levi Gross
* Delgermurun Purevkhuu
* Lewis Cowper
* Stephen Newey
* Ryan Foster
* v1kku
* Miguel Vieira
* Ben Emery
* David Smith
* Ben Margolis
* Tom Talbot
* Jeffrey Hearn
* Robert Clark
* Nathan Brizendine
* Gordon Pendleton
* John-Scott Atlakson
* Eric Drechsel
* Alejandro Giacometti
* Robert Rollins
* linibou
* Timo Rieber
* Jerel Unruh
* georgewhewell
* Frank Wiles
* Sebastian Spiegel
* Alejandro Varas
* Martin Sanders
* Benoît Bar
* Claudemiro
* Tiago Henriques
* Arne Schauf
* Jordi Joan
* Damian Moore
* signalkraft
* Mac Chapman
* Brett Grace
* Nar Chhantyal
* Michael Fillier
* Mitchel Cabuloy
* Piet Delport
* Tom Christie
* Michael van Tellingen
* Scot Hacker
* Kyungil Choi
* Joss Ingram
* Christoph Lipp
* Michael Cordover
* Timothy Allen
* Rob Shelton
* Anurag Sharma
* Maximilian Stauss
* Salvador Faria
* Alex Gleason
* Ryan Pineo
* Petr Vacha
* Sævar Öfjörð Magnússon
* Ashia Zawaduk
* Denis Voskvitsov
* Kyle Stratis
* Sergey Nikitin
* John Draper
* Rich Brennan
* Alex Bridge
* Tamriel
* LKozlowski
* Matthew Downey
* Maris Serzans
* Shu Ishida
* Ben Kerle
* Christian Peters
* Adon Metcalfe
* rayrayndwiga
* Rich Atkinson
* jnns
* Eugene MechanisM
* Benjamin Bach
* Alexander Bogushov
* Aarni Koskela
* alexpilot11
* Peter Quade
* Josh Hurd
* Matt Fozard
* Chris Rogers
* Josh Schneier
* Charlie Choiniere
* Nigel Fletton
* Kait Crawford
* Adam Bolfik
* Thomas Winter
* Gareth Price
* Liam Brenner
* Nicolas Kuttler
* Juha Kujala
* Eirik Krogstad
* Rob Moorman
* Matthijs Melissen
* Jonas Lergell
* Danielle Madeley
* Roel Bruggink
* Yannick Chabbert
* Tomas Olander
* Andrew Tork Baker
* Vincent Audebert
* Jack Paine
* Nick Smith
* João Luiz Lorencetti
* Jason Morrison
* Mario César
* Moritz Pfeiffer
* David Seddon
* Brad Busenius
* Juha Yrjölä
* Bojan Mihelac
* Robert Moggach
* Stephen Rice
* Behzad Nategh
* Yann Fouillat (Gagaro)
* Richard McMillan
* Johannes Spielmann
* Franklin Kingma
* Ludolf Takens
* Oktay Altay
* Paul J Stevens
* kakulukia
* Raphael Stolt
* Tim Graham
* Tobias Schmidt
* Chris Darko
* Aymeric Augustin
* Adriaan Tijsseling
* sebworks
* Sean Muck
* Fábio Macêdo Mendes
* Eraldo Energy
* Jesse Legg
* Tim Leguijt
* Luiz Boaretto
* Jonathon Moore
* Kees Hink
* Jayden Smith
* emg36
* Stein Strindhaug
* Žan Anderle
* Mattias Loverot
* Ricky Robinett
* Axel Haustant
* Henk-Jan van Hasselaar
* alexfromvl
* Jaap Roes
* Ducky
* Shawn Makinson
* Tom Miller
* Luca Perico
* Gary Krige
* Hammy Goonan
* Thejaswi Puthraya
* Benoît Vogel
* Manuel E. Gutierrez
* Albert O'Connor
* Morgan Aubert
* Diederik van der Boor
* Sean Hoefler
* Edd Baldry
* PyMan Claudio Marinozzi
* Jeffrey Chau
* Craig Loftus
* MattRijk
* Marco Fucci
* Mihail Russu
* Robert Slotboom
* Erick M'bwana
* Andreas Nüßlein
* John Heasly
* Nikolai Røed Kristiansen
* Alex Zagorodniuk
* glassresistor
* Mikael Svensson
* Peter Baumgartner
* Matheus Bratfisch
* Kevin Whinnery
* Martey Dodoo
* David Ray
* Alasdair Nicol
* Tobias McNulty
* Vorlif
* Kjartan Sverrisson
* Christine Ho
* Trent Holliday
* jacoor
* hdnpl
* Tom Hendrikx
* Ralph Jacobs
* Wietze Helmantel
* Patrick Gerken
* Will Giddens
* Maarten Kling
* Huub Bouma
* Thijs Kramer
* Ramon de Jezus
* Ross Curzon-Butler
* Daniel Chimeno
* Medhat Assaad
* Sebastian Bauer
* Martin Hill
* Maurice Bartnig
* Eirikur Ingi Magnusson
* Harris Lapiroff
* Hugo van den Berg
* Olly Willans
* Ben Enright
* Alice Rose
* John Franey
* Marc Tudurí
* Lucas Moeskops
* Rob van der Linde
* Paul Kamp
* David Wasylciw
* Eugene Morozov
* Levi Adler
* Edwar Baron
* Tomasz Knapik
* Venelin Stoykov
* Emily Horsman
* jcronyn
* Ben Sturmfels
* Anselm Bradford
* Mads Jensen
* Samir Shah
* Patrick Woods
* Ross Crawford-d'Heureuse
* rifuso
* Jon Carmack
* Martin Sandström
* Adrian Turjak
* Michael Palmer
* Philipp Bosch
* misraX
* Bruno Alla
* Christopher Bledsoe (The Motley Fool)
* Florent Osmont
* J Rob Gant
* Mary Kate Fain
* Dário Marcelino
* Dave Bell
* Ben Weatherman
* Carlo Ascani
* Julian Gallo
* Dan Dietz
* Michael Harrison
* Todd Dembrey
* Sebastian Brestin
* Casper Timmers
* Kevin Chung
* Kim Chee Leong
* Dan Swain
* Alexs Mathilda
* Tony Yates
* Pomax
* Arthur Holzner
* Alejandro Garza
* Rajeev J Sebastian
* Sander Tuit
* Tim Kamanin
* Sergey Fedoseev
* Harm Zeinstra
* David Moore
* Pierre Geier
* Jérôme Lebleu
* Victor Miti
* Andrew Plummer
* Dmitry Vasilev
* Benjamin Thurm
* Ed Henderson
* Strother Scott
* Daniele Procida
* Catherine Farman
* Abdulmalik Abdulwahab
* Andrew Crewdson
* Aram Dulyan
* Kevin Howbrook
* Ryan Verner
* Oliver Wilkerson
* Matthew Schinckel
* Michael Borisov
* Dan Braghis
* Ben Dickinson
* Meteor0id
* Naa Marteki Reed
* Jorge Barata
* Brady Moe
* Yi Huang
* Stas Rudakou
* Abdulaziz Alfuhigi
* Dzianis Sheka
* Scott Cranfill
* gmmoraes
* Justin Focus
* Fedor Selitsky
* Seb Brown
* Noah B Johnson
* Hillary Jeffrey
* Nick Travis
* Maylon Pedroso
* Thijs Walcarius
* mukesh5
* frmdstryr
* Aidarbek Suleimenov
* Matthew Linares
* Asanka Lihiniyagoda
* David Beitey
* Paul Vetch
* Vladimir Knobel
* Matt Collins
* Thomas Elliott
* damianosSemmle
* Evan Winter
* Neil Lyons
* Gassan Gousseinov
* Thomas Kremmel
* patta42
* Esper Kuijs
* Damian Grinwis
* Wesley van Lee
* Md Arifin Ibne Matin
* Tom Usher
* Haydn Greatnews
* Katie Locke
* Cassidy Brooke
* dthompson86
* Jason Dilworth
* Deniz Dogan
* Po-Chuan Hsieh
* scil
* Mike Hearn
* Samuel Mendes
* Adam Eikman
* Andreas Bernacca
* Alex Tomkins
* Beth Menzies
* Michael Bunsen
* Dillen Meijboom
* George Hickman
* Eric Dyken
* Jordan Bauer
* Fidel Ramos
* Quadric
* jonny5532
* William Blackie
* Andrew Miller
* Rodrigo
* Iman Syed
* John Carter
* Jonathan Liuti
* Rahmi Pruitt
* Sanyam Khurana
* Pavel Denisov
* Mikael Engström
* Zac Connelly
* Sarath Kumar Somana
* Dani Hodovic
* Janne Alatalo
* Colin Klein
* Eduard Luca
* Kiril Staikov
* Saptak Sengupta
* Dawid Bugajewski
* Brian Whitton
* Tim White
* Mike Janger
* Prithvi MK
* pySilver
* a-mere-peasant
* David T Thompson
* kailwallin
* ryanomor
* Thijs Baaijen
* Stefani Castellanos
* Aliosha Padovani
* Tom Readings
* Andrey Smirnov
* Tim Gates
* Timothy Bautista
* Pete Andrew
* Benedikt Willi
* Johannes Vogel
* Sam Costigan
* Eric Sherman
* Martin Coote
* Simon Evans
* Arkadiusz Michał Ryś
* James O'Toole
* Storm Heg
* Daniel (aritas1)
* timmysmalls
* dtwm
* Steve Lyall
* Lars van de Kerkhof
* pimarc
* minusf
* Paulo Alvarado
* Karran Besen
* Mohamed Feddad
* Michał (Quadric) Sieradzki
* Vlad Gerasimenko
* Tomonori Tanabe
* Tomas Walch
* Pascal Widdershoven

Translators
===========

* Afrikaans: Jaco du Plessis, Jared Osborn
* Arabic: Abdulaziz Alfuhigi, Roger Allen, Khaled Arnaout, Mohammed Abdul Gadir, Ahmad Kiswani, Mohamed Mayla, Ahmed Miske Sidi Med, Ultraify Media
* Armenian: Vachagan
* Basque: Unai Zalakain
* Belarusian: Stas Rudakou, Tatsiana Tsygan
* Bulgarian: Lyuboslav Petrov
* Burmese: ime11
* Catalan: Antoni Aloy, David Llop, Roger Pons
* Chinese: hanfeng, Lihan Li, Leway Colin, Orangle Liu, shengsheng gz
* Chinese (Simplified): Ed, hanfeng, Yi Huang, Daniel Hwang, Jian Li, Aosp T, Listeng Teng, Feng Wang, whuim, Fred Zeng, Joey Zhao, Vincent Zhao, zhushajun
* Chinese (Traditional): c o, gogobook, Andy Kong, Lihan Li, Jp Shieh, Yeh Yen-Ke, Yu Hsun Lee
* Croatian (Croatia): Dino Aljević, Marko Burazin, Ivica Dosen, Luka Matijević
* Czech: Ales Dvorak, Martin Galda, IT Management, Eva Mikesova, Mořeplavec, Sophy O, Martina Oleksakova, Ivan Pomykacz, Jiri Stepanek, Marek Turnovec, Mirek Zvolský
* Danish: Mads Kronborg, MRostgaard, Asger Sørensen
* Dutch: benny_AT_it_digin.com, Bram, Brecht Dervaux, Huib Keemink, Thijs Kramer, Samuel Leeuwenburg, mahulst, Rob Moorman, Michael van Tellingen, Arne Turpyn
* Dutch (Netherlands): Bram, Kees Hink, Coen van der Kamp, Franklin Kingma, Maarten Kling, Thijs Kramer, Meteor0id
* Estonian: Ragnar Rebase
* Finnish: Eetu Häivälä, Niklas Jerva, Aarni Koskela, Rauli Laine, Valter Maasalo, Glen Somerville, Juha Yrjölä
* French: Adrien, Timothy Allen, Sebastien Andrivet, Bertrand Bordage, André Bouatchidzé, Aurélien Debord, Romain Dorgueil, Tom Dyson, Antonin Enfrun, Axel Haustant, Léo, Pierre Marfoure, nahuel, Sophy O, Dominique Peretti, fpoulain, Loïc Teixeira, Benoît Vogel
* Galician: fooflare
* Georgian: André Bouatchidzé
* German: Ettore Atalan, Bohreromir, Patrick Craston, Peter Dreuw, Henrik Kröger, Tammo van Lessen, Martin Löhle, Wasilis Mandratzis-Walz, Daniel Manser, Matthias Martin, m0rph3u5, Max Pfeiffer, Moritz Pfeiffer, Herbert Poul, Karl Sander, Tobias Schmidt, Johannes Spielmann, Raphael Stolt, Benjamin Thurm, Norman Uekermann, Jannis Vajen, Vorlif, Matthew Westcott, Benedikt Willi
* Greek: Jim Dal, George Giannoulopoulos, Yiannis Inglessis, Wasilis Mandratzis-Walz, Nick Mavrakis, NeotheOne, Serafeim Papastefanos
* Haitian: Hantz Vius
* Hebrew (Israel): Lior Abazon, bjesus, Yossi Lalum, Adi Ron, Oleg Sverdlov
* Hungarian: Istvan Farkas, Laszlo Molnar, Kornél Novák Mergulhão, BN, Aron Santa
* Icelandic (Iceland): Arnar Tumi Þorsteinsson, Kjartan Sverrisson, Sævar Öfjörð Magnússon
* Indonesian (Indonesia): atmosuwiryo, Sutrisno Efendi, Dzikri Hakim, Geek Pantura, Ronggo Radityo, M. Febrian Ramadhana
* Italian: Sandro Badalamenti, Edd Baldry, Claudio Bantaloukas, Guglielmo Celata, Gian-Maria Daffre, Giacomo Ghizzani, LB (Ben Johnston), Stefano Marchetto, Carlo Miron, Alessio Di Stasio, Andrea Tagliazucchi
* Japanese: Sangmin Ahn, Shuhei Hirota, Shu Ishida, Yudai Kobayashi, Tri Minh, Hideaki Oguchi, Tomo Mizoe, Safu9, Daigo Shitara, Shimizu Taku, umepon0626, Takuya Yamamoto
* Korean: Kyungil Choi, Jihan Chung
* Latvian: Reinis Rozenbergs, Maris Serzans
* Lithuanian: Matas Dailyda
* Mongolian: Myagmarjav Enkhbileg, Delgermurun Purevkhuu
* Norwegian Bokmål: Eirik Krogstad, Ole Kristian Losvik, Robin Skahjem-Eriksen, Stein Strindhaug
* Persian: Mohammad reza Jelveh, Mohammad Hossein Mojtahedi, Hamed Najand, Py Zenberg
* Polish: Łukasz Bołdys, Konrad Lalik, Miron Levitsky, Mateusz, Miłosz Miśkiewicz, Bartek Sielicki, Grzegorz Wasilewski, Bartosz Wiśniewski
* Portuguese (Brazil): Claudemiro Alves Feitosa Neto, Bruno Bertoldi, Luiz Boaretto, Gladson Brito, Thiago Cangussu, Daniel Carvalho, Gilson Filho, Joao Garcia, João Luiz Lorencetti, Marcio Mazza, Douglas Miranda, Guilherme Nabanete
* Portuguese (Portugal): Gladson Brito, Thiago Cangussu, Tiago Henriques, Jose Lourenco, Rui Martins, Nuno Matos, Douglas Miranda, Manuela Silva
* Romanian: Dan Braghis, Bogdan Mateescu
* Russian: ajk, Andrey Avdey, Daniil, Mikhail Gerasimov, gsstver, sergeybe, Sergey Khalymon, Sergey Komarov, Miron Levitskiy, Arseni M, Eugene MechanisM, Rustam Mirzaev, Alexander Penshin, Mikalai Radchuk, Alexandr Romantsov, Mikhail Sidorov, Nikita Tonkoshkur, Tatsiana Tsygan, Viktor, Nikita Viktorovich, Vassiliy Vorobyov
* Slovak (Slovakia): Stevo Backor, dellax, Martin Janšto, Jozef Karabelly
* Slovenian: Mitja Pagon, Matej Stavanja
* Spanish: Mauricio Baeza, Daniel Chimeno, Oscar Luciano Espirilla Flores, fonso, fooflare, José Luis, Joaquín Tita, Unai Zalakain
* Swedish: Philip Andersen, Andreas Bergström, Jim Brouzoulis, Oscar Fröberg, Alexander Holmbäck, André Karlsson, Jon Karlsson, Ludwig Kjellström, Thomas Kunambi, Andreas Lans, Hannes Lohmander, Martin Sandström
* Tetum: Alessandro, Joanico Barros, Peter Coward, Mariano de Deus, Onorio de Jesus Afonso, Mario Alves Pinto
* Thai: Amawalee Combe, Jon Combe, Walaksawan Vervoort
* Turkish: Saadettin Yasir Akel, Umut Bektaş, Zafer Cengiz, Cihad Gündoǧdu, Basitlik İyidir, José Luis, Py Data, Ahmet Sarıcan, Ragıp Ünal
* Turkish (Turkey): Saadettin Yasir Akel, Basitlik İyidir, Umut Bektaş, lzm dgl, Cihad Gündoǧdu, Ahmet Serdar Karadeniz, Fatih Koç koç, José Luis, Py Data, Ragıp Ünal
* Ukrainian: Vladislav Herasimenko, Mikolai Incognito, Sergiy Shkodenko, Viktor Shytiuk, Ivan Tyshchenko, Zoriana Zaiats, Mykola Zamkovoi
* Vietnamese: Hồng Quân Nguyễn, Luan Nguyen
* Welsh: Adam Hughes
